Author: mturk
Date: Fri Jul 3 06:34:41 2009
New Revision: 790802
URL:
http://svn.apache.org/viewvc?rev=790802&view=revLog:
One more (final) rename
Added:
commons/sandbox/runtime/trunk/src/main/java/org/apache/commons/runtime/NativePointer.java
- copied, changed from r790799, commons/sandbox/runtime/trunk/src/main/java/org/apache/commons/runtime/VoidPointer.java
Removed:
commons/sandbox/runtime/trunk/src/main/java/org/apache/commons/runtime/VoidPointer.java
Modified:
commons/sandbox/runtime/trunk/src/main/java/org/apache/commons/runtime/DirectBuffer.java
commons/sandbox/runtime/trunk/src/main/java/org/apache/commons/runtime/Pointer32.java
commons/sandbox/runtime/trunk/src/main/java/org/apache/commons/runtime/Pointer64.java
commons/sandbox/runtime/trunk/src/main/native/shared/pointer.c
commons/sandbox/runtime/trunk/src/test/org/apache/commons/runtime/TestMemory.java
Modified: commons/sandbox/runtime/trunk/src/main/java/org/apache/commons/runtime/DirectBuffer.java
URL:
http://svn.apache.org/viewvc/commons/sandbox/runtime/trunk/src/main/java/org/apache/commons/runtime/DirectBuffer.java?rev=790802&r1=790801&r2=790802&view=diff==============================================================================
--- commons/sandbox/runtime/trunk/src/main/java/org/apache/commons/runtime/DirectBuffer.java (original)
+++ commons/sandbox/runtime/trunk/src/main/java/org/apache/commons/runtime/DirectBuffer.java Fri Jul 3 06:34:41 2009
@@ -18,7 +18,7 @@
import org.apache.commons.runtime.util.Utils;
-/**
+/**
* Represents the {@code Pointer} as buffer.
*
* @since Runtime 1.0
Copied: commons/sandbox/runtime/trunk/src/main/java/org/apache/commons/runtime/NativePointer.java (from r790799, commons/sandbox/runtime/trunk/src/main/java/org/apache/commons/runtime/VoidPointer.java)
URL:
http://svn.apache.org/viewvc/commons/sandbox/runtime/trunk/src/main/java/org/apache/commons/runtime/NativePointer.java?p2=commons/sandbox/runtime/trunk/src/main/java/org/apache/commons/runtime/NativePointer.java&p1=commons/sandbox/runtime/trunk/src/main/java/org/apache/commons/runtime/VoidPointer.java&r1=790799&r2=790802&rev=790802&view=diff==============================================================================
--- commons/sandbox/runtime/trunk/src/main/java/org/apache/commons/runtime/Pointer32.java (original)
+++ commons/sandbox/runtime/trunk/src/main/java/org/apache/commons/runtime/Pointer32.java Fri Jul 3 06:34:41 2009
@@ -24,7 +24,7 @@
* </p>
* @since Runtime 1.0
*/
-class Pointer32 extends VoidPointer {
+class Pointer32 extends NativePointer {
protected int CLEANUP;
protected int POINTER;
Modified: commons/sandbox/runtime/trunk/src/main/java/org/apache/commons/runtime/Pointer64.java
URL:
http://svn.apache.org/viewvc/commons/sandbox/runtime/trunk/src/main/java/org/apache/commons/runtime/Pointer64.java?rev=790802&r1=790801&r2=790802&view=diff==============================================================================
--- commons/sandbox/runtime/trunk/src/main/java/org/apache/commons/runtime/Pointer64.java (original)
+++ commons/sandbox/runtime/trunk/src/main/java/org/apache/commons/runtime/Pointer64.java Fri Jul 3 06:34:41 2009
@@ -24,7 +24,7 @@
* </p>
* @since Runtime 1.0
*/
-class Pointer64 extends VoidPointer {
+class Pointer64 extends NativePointer {
protected long CLEANUP;
protected long POINTER;
Modified: commons/sandbox/runtime/trunk/src/main/native/shared/pointer.c
URL:
http://svn.apache.org/viewvc/commons/sandbox/runtime/trunk/src/main/native/shared/pointer.c?rev=790802&r1=790801&r2=790802&view=diff==============================================================================
--- commons/sandbox/runtime/trunk/src/main/native/shared/pointer.c (original)
+++ commons/sandbox/runtime/trunk/src/main/native/shared/pointer.c Fri Jul 3 06:34:41 2009
@@ -123,7 +123,7 @@
}
#endif
-ACR_JNI_EXPORT_DECLARE(jobject, VoidPointer, nullp0)(ACR_JNISTDARGS)
+ACR_JNI_EXPORT_DECLARE(jobject, NativePointer, nullp0)(ACR_JNISTDARGS)
{
UNREFERENCED_O;
if (!_clazzn.i) {
@@ -132,7 +132,7 @@
return ACR_PointerCreate(_E, 0, 0, NULL);
}
-ACR_JNI_EXPORT_DECLARE(void, VoidPointer, cleanup0)(ACR_JNISTDARGS)
+ACR_JNI_EXPORT_DECLARE(void, NativePointer, cleanup0)(ACR_JNISTDARGS)
{
if (_clazzn.i && J4MID(0000)) {
acr_pointer_cleanup_fn_t *cleanup;
@@ -157,7 +157,7 @@
}
-ACR_JNI_EXPORT_DECLARE(void, VoidPointer, cleanup1)(ACR_JNISTDARGS)
+ACR_JNI_EXPORT_DECLARE(void, NativePointer, cleanup1)(ACR_JNISTDARGS)
{
if (_clazzn.i && J4MID(0000)) {
acr_pointer_cleanup_fn_t *cleanup;
Modified: commons/sandbox/runtime/trunk/src/test/org/apache/commons/runtime/TestMemory.java
URL:
http://svn.apache.org/viewvc/commons/sandbox/runtime/trunk/src/test/org/apache/commons/runtime/TestMemory.java?rev=790802&r1=790801&r2=790802&view=diff==============================================================================
--- commons/sandbox/runtime/trunk/src/test/org/apache/commons/runtime/TestMemory.java (original)
+++ commons/sandbox/runtime/trunk/src/test/org/apache/commons/runtime/TestMemory.java Fri Jul 3 06:34:41 2009
@@ -310,7 +310,7 @@
public void testPointerNull()
throws Throwable
{
- assertTrue("Not null", VoidPointer.NULL.IsNull());
+ assertTrue("Not null", Pointer.NULL.IsNull());
}
--- commons/sandbox/runtime/trunk/src/main/java/org/apache/commons/runtime/VoidPointer.java (original)
+++ commons/sandbox/runtime/trunk/src/main/java/org/apache/commons/runtime/NativePointer.java Fri Jul 3 06:34:41 2009
@@ -16,13 +16,13 @@
package org.apache.commons.runtime;
/** Represents the Operating System C/C++ pointer.
* <p>
* <b>Warning:</b><br/>Using this class improperly may crash the running JVM.
* </p>
* @since Runtime 1.0
*/
-public abstract class VoidPointer implements Pointer
+public abstract class NativePointer implements Pointer
{
/**
@@ -34,7 +34,7 @@
* </p>
*
*/
- public static Pointer createInstance()
+ public static final Pointer createInstance()
{
if (Platform.SIZEOF_POINTER == 8)
return new Pointer32();
@@ -46,7 +46,7 @@
* Pointer can only be created from the native code.
* Suppress any instantiation except from internal classes.
*/
- protected VoidPointer()
+ protected NativePointer()
{
// No Instance
}
@@ -16,13 +16,13 @@
package org.apache.commons.runtime;
-/** Represents the Operating System C/C++ pointer.
+/** Represents the Operating System C/C++ native pointer.
* <p>
* <b>Warning:</b><br/>Using this class improperly may crash the running JVM.
Modified: commons/sandbox/runtime/trunk/src/main/java/org/apache/commons/runtime/Pointer32.java
URL:
http://svn.apache.org/viewvc/commons/sandbox/runtime/trunk/src/main/java/org/apache/commons/runtime/Pointer32.java?rev=790802&r1=790801&r2=790802&view=diff==============================================================================